summaryrefslogtreecommitdiff
path: root/mali_kbase/mali_kbase_mem_linux.h
diff options
context:
space:
mode:
authorSidath Senanayake <sidaths@google.com>2019-05-06 12:21:44 +0200
committerSidath Senanayake <sidaths@google.com>2019-05-06 12:21:44 +0200
commitac90f0dd5fbae0b94e9720203a8bb2e81fd4b679 (patch)
treeb8939b75ce4e0f1e8ae07e36648edef7f3a3ce59 /mali_kbase/mali_kbase_mem_linux.h
parente972f6531ef8c9d01eae567f52db4f0fd37d1428 (diff)
downloadgpu-ac90f0dd5fbae0b94e9720203a8bb2e81fd4b679.tar.gz
Mali Bifrost DDK r18p0 KMD
Provenance: ee36a6687 (collaborate/EAC/b_r18p0) BX304L01B-BU-00000-r18p0-01rel0 BX304L06A-BU-00000-r18p0-01rel0 BX304X07X-BU-00000-r18p0-01rel0 Signed-off-by: Sidath Senanayake <sidaths@google.com> Change-Id: Ie26cb00b475d697c2778306ac09c6a799201ac77
Diffstat (limited to 'mali_kbase/mali_kbase_mem_linux.h')
-rw-r--r--mali_kbase/mali_kbase_mem_linux.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/mali_kbase/mali_kbase_mem_linux.h b/mali_kbase/mali_kbase_mem_linux.h
index 5cb88d1..e34972f 100644
--- a/mali_kbase/mali_kbase_mem_linux.h
+++ b/mali_kbase/mali_kbase_mem_linux.h
@@ -1,6 +1,6 @@
/*
*
- * (C) COPYRIGHT 2010, 2012-2018 ARM Limited. All rights reserved.
+ * (C) COPYRIGHT 2010, 2012-2019 ARM Limited. All rights reserved.
*
* This program is free software and is provided to you under the terms of the
* GNU General Public License version 2 as published by the Free Software
@@ -129,15 +129,15 @@ int kbase_mem_flags_change(struct kbase_context *kctx, u64 gpu_addr, unsigned in
int kbase_mem_commit(struct kbase_context *kctx, u64 gpu_addr, u64 new_pages);
/**
* kbase_mmap - Mmap method, gets invoked when mmap system call is issued on
* device file /dev/malixx.
* @file: Pointer to the device file /dev/malixx instance.
* @vma: Pointer to the struct containing the info where the GPU allocation
* will be mapped in virtual address space of CPU.
*
* Return: 0 on success or error code
*/
-int kbase_mmap(struct file *file, struct vm_area_struct *vma);
+int kbase_context_mmap(struct kbase_context *kctx, struct vm_area_struct *vma);
/**
* kbase_mem_evictable_init - Initialize the Ephemeral memory eviction
@@ -129,15 +129,15 @@ int kbase_mem_flags_change(struct kbase_context *kctx, u64 gpu_addr, unsigned in
int kbase_mem_commit(struct kbase_context *kctx, u64 gpu_addr, u64 new_pages);
/**
- * kbase_mmap - Mmap method, gets invoked when mmap system call is issued on
- * device file /dev/malixx.
- * @file: Pointer to the device file /dev/malixx instance.
+ * kbase_context_mmap - Memory map method, gets invoked when mmap system call is
+ * issued on device file /dev/malixx.
+ * @kctx: The kernel context
* @vma: Pointer to the struct containing the info where the GPU allocation
* will be mapped in virtual address space of CPU.